# Jupyter Notebook tutorials

If you [clone](https://help.github.com/en/articles/cloning-a-repository) or [download](https://github.com/kinverarity1/aseg_gdf2/archive/master.zip) this repository, you will be able to execute and modify these tutorials on your own machine:

- [Tutorial 1: Quick start](tutorial1.ipynb)
- [Tutorial 2: Reading large files by line number](tutorial2.ipynb)
- [Tutorial 3: Use dask to read a DAT file too big to fit in memory](tutorial3.ipynb)

